#ifndef BASEALT_SPICE_EC_ERRORS_H
#define BASEALT_SPICE_EC_ERRORS_H

#include <stdexcept>

#include <QString>

namespace Basealt {

class NetworkException : public std::runtime_error
{
public:
    NetworkException( const QString& reason )
        : std::runtime_error( "Network error: " + reason.toStdString() )
    {
    }
};

class JsonParsingException : public std::runtime_error
{
public:
    JsonParsingException( const QString& reason )
        : std::runtime_error( "Json parsing error: " + reason.toStdString() )
    {
    }
};

class TokenParsingException : public JsonParsingException
{
public:
    TokenParsingException( const QString& reason )
        : JsonParsingException( "Auth token parsing error: " + reason )
    {
    }
};

class VirtualMachineParsingException : public JsonParsingException
{
public:
    VirtualMachineParsingException( const QString& reason )
        : JsonParsingException( "Virtual machines parsing error: " + reason )
    {
    }
};

class NodesParsingException : public JsonParsingException
{
public:
    NodesParsingException( const QString& reason )
        : JsonParsingException( "Nodes parsing error: " + reason )
    {
    }
};

class DataEntryParsingException : public JsonParsingException
{
public:
    DataEntryParsingException( const QString& reason )
        : JsonParsingException( "Data entry parsing error: " + reason )
    {
    }
};

class ProxmoxClientException : public std::runtime_error
{
public:
    ProxmoxClientException( const QString& reason )
        : std::runtime_error( "Proxmox client error: " + reason.toStdString() )
    {
    }
};

class SpiceRemoteViewerException : public std::runtime_error
{
public:
    SpiceRemoteViewerException( const QString& reason )
        : std::runtime_error( "Spice remote viewer error: " + reason.toStdString() )
    {
    }
};

class NodeException : public std::runtime_error
{
public:
    NodeException( const QString& reason )
        : std::runtime_error( "Node error: " + reason.toStdString() )
    {
    }
};

} // namespace Basealt

#endif // BASEALT_SPICE_EC_ERRORS_H
