#ifndef BASEALT_SPICE_EC_MAIN_VIEW_CONTROLLER_H
#define BASEALT_SPICE_EC_MAIN_VIEW_CONTROLLER_H

#include <memory>

#include "main-view.h"
#include "proxmox-client.h"
#include "isettings-manager.h"

namespace Basealt {

class MainViewController : public QObject
{
    Q_OBJECT
public:
    MainViewController( std::unique_ptr<ISettingsManager> manager );

    void bind( const std::shared_ptr<MainView>& view );

signals:
    void done();

private slots:
    void onServerURLChanged( const QString& serverURL );
    void onVirtualMachineIDChanged( const QString& vmid );
    void onUsernameChanged( const QString& username );
    void onPasswordChanged( const QString& password );
    void onRememberMeStateChanged( bool isChecked );
    void onIgnoreSslErrorsStateChanged( bool isChecked );
    void onConnectButtonClicked();
    void onCancelButtonClicked();

    void onLoginSucceeded();
    void onNodesFetched( const std::vector<std::shared_ptr<Node>>& nodes );
    void onVirtualMachinesFetched( const std::vector<std::shared_ptr<VirtualMachine>>& vms );
    void onVirtualMachineStateFetched( VirtualMachine::Status state );
    void onVirtualMachineStatusSet();
    void onVirtualMachineSpiceProxyFetched( const QString& spiceProxyFilePath );

    void onErrorOccured( const QString& reason );

    void checkVirtualMachineStatus();

private:
    std::unique_ptr<ISettingsManager> _settingsManager;
    std::shared_ptr<MainView> _view;

    std::shared_ptr<ProxmoxClient> _client;
    std::shared_ptr<VirtualMachine> _virtualMachine;

    QString _serverURL;
    size_t _virtualMachineID;
    QString _username;
    QString _password;
    bool _rememberMe;
    bool _ignoreSslErrors;

    void bind( ProxmoxClient* client );
    void bind( VirtualMachine* virtualMachine );

    void restoreViewState();
};

} // namespace Basealt

#endif // BASEALT_SPICE_EC_MAIN_VIEW_CONTROLLER_H
