#ifndef BASEALT_SPICE_EC_MAIN_VIEW_H
#define BASEALT_SPICE_EC_MAIN_VIEW_H

#include <QMainWindow>
#include <QStackedWidget>

#include "settings-view.h"
#include "process-view.h"

namespace Basealt {

class MainView : public QMainWindow
{
    Q_OBJECT
public:
    MainView( QWidget* parent = nullptr, 
              Qt::WindowFlags flags = Qt::WindowFlags() );

    inline void showSpinner();
    inline void hideSpinner();

    inline SettingsView* settingsView() const;
    inline ProcessView* processView() const;

    void reportError( const QString& reason );

private:
    QStackedWidget* _stackedView;
    SettingsView* _settingsView;
    ProcessView* _processView;
};

inline void MainView::showSpinner()
{
    _stackedView->setCurrentWidget( _processView );
}

inline void MainView::hideSpinner()
{
    _stackedView->setCurrentWidget( _settingsView );
}

inline SettingsView* MainView::settingsView() const
{
    return _settingsView;
}

inline ProcessView* MainView::processView() const
{
    return _processView;
}

} // namespace Basealt

#endif // BASEALT_SPICE_EC_MAIN_VIEW_H

