#ifndef BASEALT_SPICE_EC_PROXMOX_CLIENT_H
#define BASEALT_SPICE_EC_PROXMOX_CLIENT_H

#include <memory>
#include <vector>

#include "proxmox-rest-client.h"
#include "proxmox-virtual-machine.h"
#include "proxmox-user.h"
#include "proxmox-node.h"
#include "errors.h"

namespace Basealt {

class ProxmoxClient : public QObject
{
    Q_OBJECT
public:
    ProxmoxClient( const QString& serverURL, bool ignoreSslErrors );

    void login( const QString& username, const QString& password );

    void fetchNodes();

signals:
    void loginSucceeded();
    void loginFailed( const QString& reason );

    void nodesFetched( const std::vector<std::shared_ptr<Node>>& nodes );
    void nodesFetchFailed( const QString& reason );

private slots:
    void onReplyFinished( QNetworkReply* reply );

private:
    std::shared_ptr<ProxmoxRestClient> _restClient;

    QNetworkReply* _loginReply;
    QNetworkReply* _fetchNodesReply;
    
    std::shared_ptr<User> _user;
    std::vector<std::shared_ptr<Node>> _nodes;

    std::vector<std::shared_ptr<Node>>
    processFetchNodesReply( QNetworkReply* reply );
};

} // namespacec Basealt

#endif // BASEALT_SPICE_EC_PROXMOX_CLIENT_H

