#ifndef BASEALT_SPICE_EC_REST_CLIENT_H
#define BASEALT_SPICE_EC_REST_CLIENT_H

#include <memory>

#include <QNetworkAccessManager>
#include <QNetworkReply>

#include "proxmox-user.h"

namespace Basealt {

class ProxmoxRestClient : public QObject
{
    Q_OBJECT
public:
    ProxmoxRestClient( const QString& baseURL, bool ignoreSslErrors );

    inline void setUser( const std::shared_ptr<User>& user );
    inline QUrl url() const;

    QNetworkReply* get( const QString& endpoint );
    QNetworkReply* post( const QString& endpoint,
                         const QByteArray& data );
signals:
    void finished( QNetworkReply* reply );

private slots:
    void onSslErrors( QNetworkReply* reply,
                      const QList<QSslError>& errors );
private:
    QUrl _baseURL;
    std::shared_ptr<User> _user;
    QNetworkAccessManager _networkManager;
    bool _ignoreSslErrors;
};

inline void ProxmoxRestClient::setUser( const std::shared_ptr<User>& user )
{
    _user = user;
}

inline QUrl ProxmoxRestClient::url() const
{
    return _baseURL;
}

} // namespace Basealt

#endif // BASEALT_SPICE_EC_REST_CLIENT_H
