#ifndef BASEALT_SPICE_EC_VIRTUAL_MACHINE_H
#define BASEALT_SPICE_EC_VIRTUAL_MACHINE_H

#include <memory>

#include "proxmox-rest-client.h"

namespace Basealt {

class VirtualMachine : public QObject
{
    Q_OBJECT
public:
    enum class Status
    {
        Running,
        Paused,
        Stopped        
    };

    VirtualMachine( const std::shared_ptr<ProxmoxRestClient>& restClient,
                    size_t vmID,
                    const QString& nodeID );
    
    void fetchStatus();
    void fetchSpiceProxy();

    inline size_t id() const;

    void setStatus( Status newStatus );

signals:
    void statusFetched( Status status );
    void statusFetchFailed( const QString& reason );

    void spiceProxyFetched( const QString& spiceProxyFilePath );
    void spiceProxyFetchFailed( const QString& reason );

    void statusSet();
    void setStatusFailed( const QString& reason );

private slots:
    void onReplyFinished( QNetworkReply* reply );

private:
    std::shared_ptr<ProxmoxRestClient> _restClient;
    size_t _vmID;
    QString _nodeID;

    QNetworkReply* _fetchStatusReply;
    QNetworkReply* _fetchSpiceProxyReply;
    QNetworkReply* _setStatusReply;
};

inline size_t VirtualMachine::id() const
{
    return _vmID;
}

} // namespace Basealt

#endif // BASEALT_SPICE_EC_VIRTUAL_MACHINE_H

