#ifndef BASEALT_SPICE_EC_SETTINGS_WIDGET_H
#define BASEALT_SPICE_EC_SETTINGS_WIDGET_H

#include <QLineEdit>
#include <QCheckBox>
#include <QPushButton>

namespace Basealt {

class SettingsView : public QWidget
{
    Q_OBJECT
public:
    SettingsView( QWidget* parent = nullptr,
                  Qt::WindowFlags flags = Qt::WindowFlags() );

    inline void setServerURL( const QString& serverURL );
    inline void setVirtualMachineID( size_t vmid );
    inline void setUsername( const QString& username );
    inline void setPassword( const QString& password );
    inline void setRememberMeState( bool isChecked );
    inline void setIgnoreSslErrorsState( bool isChecked );

signals:
    void serverURLChanged( const QString& serverURL );
    void virtualMachineIDChanged( const QString& vmid );
    void usernameChanged( const QString& username );
    void passwordChanged( const QString& password );
    void rememberMeStateChanged( bool isChecked );
    void ignoreSslErrorsStateChanged( bool isChecked );
    void connectButtonClicked();

private slots:
    void onServerURLEditingFinished();
    void onVirtualMachineIDEditingFinished();
    void onUsernameEditingFinished();
    void onPasswordEditingFinished();
    void onRememberMeToggled( int state );
    void onIgnoreSslErrorsToggled( int state );

private:
    QLineEdit* _serverURLLineEdit;
    QLineEdit* _virtualMachineIDLineEdit;
    QLineEdit* _usernameLineEdit;
    QLineEdit* _passwordLineEdit;
    QCheckBox* _rememberMeCheckBox;
    QCheckBox* _ignoreSslErrorsCheckBox;

    QLineEdit* makeServerURLLineEdit();
    QLineEdit* makeVirtualMachineIDLineEdit();
    QLineEdit* makeUsernameLineEdit();
    QLineEdit* makePasswordLineEdit();
    QCheckBox* makeRememberMeCheckBox();
    QCheckBox* makeIgnoreSslErrorsCheckBox();
    QPushButton* makeConnectPushButton();
};

inline void SettingsView::setServerURL( const QString& serverURL )
{
    _serverURLLineEdit->setText( serverURL );
}

inline void SettingsView::setVirtualMachineID( size_t id )
{
    _virtualMachineIDLineEdit->setText( QString::number( id ) );
}

inline void SettingsView::setUsername( const QString& username )
{
    _usernameLineEdit->setText( username );
}

inline void SettingsView::setPassword( const QString& password )
{
    _passwordLineEdit->setText( password );
}

inline void SettingsView::setRememberMeState( bool isChecked )
{
    _rememberMeCheckBox->setCheckState( isChecked ? Qt::Checked
                                                  : Qt::Unchecked );
}

inline void SettingsView::setIgnoreSslErrorsState( bool isChecked )
{
    _ignoreSslErrorsCheckBox->setCheckState( isChecked ? Qt::Checked
                                                       : Qt::Unchecked );
}

} // namespace Basealt

#endif // BASEALT_SPICE_EC_SETTINGS_WIDGET_H
