#include <QApplication>

#include <memory>

#include <QCommandLineParser>

#include "config.h"
#include "main-view-controller.h"
#include "insecure-settings-manager.h"

namespace {

const QString kVersionFormat = "%1.%2.%3";

const QString kOrganizationName = "Basealt";

} // namespace

int main( int argc, char* argv[] )
{
    QApplication app( argc, argv );

    QApplication::setApplicationVersion( QString( kVersionFormat )
                                         .arg( QString::number( VERSION_MAJOR ),
                                               QString::number( VERSION_MINOR ),
                                               QString::number( VERSION_PATCH ) ) );

    QApplication::setApplicationName( APPLICATION_NAME );
    QApplication::setOrganizationName( kOrganizationName );

    QCommandLineParser parser;
    parser.setApplicationDescription( APPLICATION_DESCRIPTION );
    const auto helpOption = parser.addHelpOption();
    const auto versionOption = parser.addVersionOption();

    parser.process( app );

    if( parser.isSet( helpOption ) )
    {
        parser.showHelp();
        return 0;
    }

    if( parser.isSet( versionOption ) )
    {
        parser.showVersion();
        return 0;
    }

    Basealt::MainViewController controller( std::make_unique<Basealt::InsecureSettingsManager>() );
    const auto view = std::make_shared<Basealt::MainView>();

    controller.bind( view );

    QObject::connect( &controller,
                      &Basealt::MainViewController::done,
                      &app,
                      &QApplication::quit );

    view->show();

    return app.exec();
}

