#include "process-view.h"

#include <unordered_map>

#include <QVBoxLayout>
#include <QPushButton>
#include <QLabel>

#include "waitingspinnerwidget.h"

#include "enum-class-hash.h"

namespace {

const QString kCancelButtonLabel = "Cancel";

const std::unordered_map<Basealt::ApplicationState,
                         QString,
                         Basealt::EnumClassHash> kStateDescription
{
    { Basealt::ApplicationState::Idle, "Doing nothing ..." },
    { Basealt::ApplicationState::Logging, "Logging ..." },
    { Basealt::ApplicationState::FetchingNodes, "Fetching nodes ..." },
    { Basealt::ApplicationState::FetchingVMs, "Fetching virtual machines ..." },
    { Basealt::ApplicationState::FetchingVMState, "Fetching virtual machine state ..." },
    { Basealt::ApplicationState::StartingVM, "Starting virtual machine ..." },
    { Basealt::ApplicationState::FetchingSpiceTicket, "Fetching SPICE ticket ..." },
    { Basealt::ApplicationState::RunningViewer, "Running remote viewer ..." }
};

} // namespace

namespace Basealt {

ProcessView::ProcessView( QWidget* parent, Qt::WindowFlags flags )
    : QWidget( parent, flags ),
      _stateLabel( new QLabel( kStateDescription.at( ApplicationState::Idle ) ) )
{
    const auto cancelPushButton = new QPushButton( kCancelButtonLabel );

    connect( cancelPushButton,
             &QPushButton::clicked,
             this,
             &ProcessView::cancelButtonClicked );

    auto spinner = new WaitingSpinnerWidget( nullptr, false, false );

    spinner->setRoundness( 70.0 );
    spinner->setMinimumTrailOpacity( 15.0 );
    spinner->setTrailFadePercentage( 70.0 );
    spinner->setNumberOfLines( 12 );
    spinner->setLineLength( 30 );
    spinner->setLineWidth( 10 );
    spinner->setInnerRadius( 20 );
    spinner->setRevolutionsPerSecond( 1 );
    spinner->setColor( QColor( 255, 255, 255 ) );

    spinner->start();

    const auto processWidgetLayout = new QVBoxLayout();
    processWidgetLayout->addWidget( spinner, 0, Qt::AlignCenter );
    processWidgetLayout->addWidget( _stateLabel );
    processWidgetLayout->addWidget( cancelPushButton, 0, Qt::AlignHCenter );

    setLayout( processWidgetLayout );
}

void ProcessView::setState( ApplicationState newState )
{
    _stateLabel->setText( kStateDescription.at( newState ) );
}

} // namespace Basealt
